summaryrefslogtreecommitdiff
path: root/build-aux
diff options
context:
space:
mode:
authorAleksander Morgado <aleksander@aleksander.es>2021-04-22 14:30:59 +0200
committerAleksander Morgado <aleksander@aleksander.es>2021-04-23 23:14:30 +0200
commitd536677efa7e4359d2591e36be7d142948c6a2b9 (patch)
tree9fa24330df59539110126944e69804f982401ada /build-aux
parent0b1906618eb47b8bd37fba61507259ef09584031 (diff)
downloadlibqmi-d536677efa7e4359d2591e36be7d142948c6a2b9.tar.gz
libqmi-glib,dpm: add service definition
The Data Port Mapper service provides a way to map hardware endpoint ids to the ep-type/ep-iface-number fields we would normally use in "WDA Get/Set Data Format" or "WDS Bind Mux Data Port". This mapping seems to be required in setups using the IPA driver, e.g. as seen in the mmdata_port_cfg() method of the modem-data-manager tool provided by the CodeAurora project under the Linux Foundation: https://source.codeaurora.org/quic/dataservices/modem-data-manager
Diffstat (limited to 'build-aux')
-rw-r--r--build-aux/qmi-codegen/utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/build-aux/qmi-codegen/utils.py b/build-aux/qmi-codegen/utils.py
index 59fb68b2..2ad66321 100644
--- a/build-aux/qmi-codegen/utils.py
+++ b/build-aux/qmi-codegen/utils.py
@@ -70,8 +70,8 @@ def add_header_start(f, output_name, service):
"#include <gio/gio.h>\n"
"\n"
"#include \"qmi-enums.h\"\n")
- # CTL and GMS don't have enums
- if service not in ('CTL', 'GMS'):
+ # CTL, DPM and GMS don't have enums
+ if service not in ('CTL', 'DPM', 'GMS'):
template += (
"#include \"qmi-enums-${service}.h\"\n")
if service == 'CTL':